==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/qbsprojectmanager/qbspropertylineedit.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QBSPROPERTYLINEEDIT_H
#define QBSPROPERTYLINEEDIT_H

#include <utils/basevalidatinglineedit.h>

#include <QList>
#include <QPair>

namespace QbsProjectManager {
namespace Internal {

class QbsPropertyLineEdit : public Utils::BaseValidatingLineEdit
{
    Q_OBJECT

public:
    explicit QbsPropertyLineEdit(QWidget *parent = 0);

    QList<QPair<QString, QString> > properties() const;

signals:
    void propertiesChanged() const;

private:
    bool validate(const QString &value, QString *errorMessage) const;

    mutable QList<QPair<QString, QString> > m_propertyCache;
};

} // namespace Internal
} // namespace QbsProjectManager

#endif // QBSPROPERTYLINEEDIT_H

==> qt-creator-opensource-src-3.2.2.zip: qt-creator-opensource-src-3.2.2/src/plugins/qbsprojectmanager/qbspropertylineedit.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QBSPROPERTYLINEEDIT_H
#define QBSPROPERTYLINEEDIT_H

#include <utils/fancylineedit.h>

#include <QList>
#include <QPair>

namespace QbsProjectManager {
namespace Internal {

class QbsPropertyLineEdit : public Utils::FancyLineEdit
{
    Q_OBJECT

public:
    explicit QbsPropertyLineEdit(QWidget *parent = 0);

    QList<QPair<QString, QString> > properties() const;

signals:
    void propertiesChanged() const;

private:
    bool validate(const QString &value, QString *errorMessage) const;

    mutable QList<QPair<QString, QString> > m_propertyCache;
};

} // namespace Internal
} // namespace QbsProjectManager

#endif // QBSPROPERTYLINEEDIT_H
